1.15.3 — Rucio 1.2 documentation

# 1.15.3

## General

### Enhancements

- Documentation: Fixing some typos in documentation #867
- Release management: generate release notes script limited to github api page limit #862
- Release management: Commit message hook does not work with CLI message #870

### Bugs

- Core & Internals: importlib not python 2.6 compatible #875
- Core & Internals: dids: setting events with set_metadata fails #943
- Documentation: Fixing grammatical errors in the documentation #886
- Documentation: RSE expressions link not working #910

## Clients

### Enhancements

- Clients: Sorting of replicas in list_replicas #668
- Clients: Fix client dependencies for python3 #930
- Clients: Add more python version support in setup_rucio_client.py #938

### Bugs

- Clients: Rucio Upload Should Respect verify_checksum Flag #847

## WebUI

### Enhancements

- WebUI: Pretty print json in subscriptions table #913